import importlib
from . import command

switcher = {
        1: "Homebrew",
        2: "Oh-my-zsh"
    }

def run():
    """Main Function"""
    
    print("You are running MacOS")
    command.print_choice(switcher)
    value = command.check_input()
    exit = command.run_input(switcher, value)
    if exit == 0:
        run()
    else: 
        quit()
        
    
    
        


if __name__ == "__main__":
    run()


import importlib
def installation_finished():
        input_user = str(input("Would you like to install something else ? Default yes (y/n) ") or "y")
        if input_user.lower().startswith('y'):
            return 0
        else:
            return 1
            


def run_input(switch, value):
    string_value = switch.get(value, "Invalid Value")
    if string_value != 'Invalid Value':
        mymodule = importlib.import_module("." + string_value, package=__package__)
        return_code = mymodule.run()
        if return_code is 0:
            print("Command Successfull")
            
        else:
            print("An error occured during the execution")
            print("Please check the logs to see what was the cause and run the command again")
        return installation_finished()
    print("Invalid Value")
    return 0


def check_input():
    """Checks the type of the input and keeps asking if not an int """
    
    value = input("What would you like to install ? ")
    while not value.isdigit():
        value = input("What would you like to install ? (A number please) ")
    return int(value)

    

def print_choice(switcher_value):
    """Prints all the available choices"""
    print("----------------------")
    
    for key in switcher_value:
        print(str(key) + " - " + str(switcher_value[key]))

    print("----------------------")



import subprocess
def run_process(command_execute):
    process = subprocess.Popen(command_execute, 
                           stdout=subprocess.PIPE,
                           shell=True,
                           universal_newlines=True)
    return_code_script = None
    
    while True:
        output = process.stdout.readline()
        print(output.strip())
        # Do something else
        return_code = process.poll()
        if return_code is not None:
            return_code_script = return_code
            # Process has finished, read rest of the output 
            for output in process.stdout.readlines():
                print(output.strip())
            break
    return return_code_script


import platform
from macos import mac
import signal
import sys

def signal_handler(signal, frame):
    print("\nGracefully exiting")
    sys.exit(0)

def main():
    platform_name = platform.system()
    if platform_name == "Darwin":
        mac.run()
        

signal.signal(signal.SIGINT, signal_handler)



if __name__ == "__main__":
    main()


import setuptools


# rm -rf dist/  
# python3 setup.py sdist bdist_wheel 
# python3 -m twine upload --repository pypi dist/*

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="oli", # Replace with your own username
    version="0.0.14",
    author="StanGirard",
    author_email="stan@primates.dev",
    description="One Liner Installer for Linux & MacOs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/StanGirard/OneLiners",
    packages=["oli","oli.macos"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    entry_points={
		'console_scripts':[
			'oli = oli.run:main',
		],
	},
)